==> libcec_3.0.1+dfsg2.orig.tar.xz: libcec-libcec-3.0.1/src/libcec/platform/util/edid.h <==
#pragma once
/*
 * This file is part of the libCEC(R) library.
 *
 * libCEC(R) is Copyright (C) 2011-2015 Pulse-Eight Limited.  All rights reserved.
 * libCEC(R) is an original work, containing original code.
 *
 * libCEC(R) is a trademark of Pulse-Eight Limited.
 *
 * This program is dual-licensed; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 *
 *
 * Alternatively, you can license this library under a commercial license,
 * please contact Pulse-Eight Licensing for more information.
 *
 * For more information contact:
 * Pulse-Eight Licensing       <license@pulse-eight.com>
 *     http://www.pulse-eight.com/
 *     http://www.pulse-eight.net/
 */

#include "env.h"

namespace PLATFORM
{
  class CEDIDParser
  {
  public:
    static uint16_t GetPhysicalAddress(void);

    static uint16_t GetPhysicalAddressFromEDID(unsigned char *data, size_t size)
    {
      return GetPhysicalAddressFromEDID((char *)data, size);
    }

    static uint16_t GetPhysicalAddressFromEDID(char *data, size_t size)
    {
      uint16_t iPA(0);

      for (size_t iPtr = 0; iPtr < size - 4; iPtr++)
      {
        if (data[iPtr]     == 0x03 &&
            data[iPtr + 1] == 0x0C &&
            data[iPtr + 2] == 0x0)
        {
          //found the hdmi marker
          iPA = (data[iPtr + 3] << 8) + data[iPtr + 4];
          break;
        }
      }

      return iPA;
    }
  };
}

==> libcec_4.0.2+dfsg1.orig.tar.xz: libcec-libcec-4.0.2/src/libcec/platform/util/edid.h <==
#pragma once
/*
 * This file is part of the libCEC(R) library.
 *
 * libCEC(R) is Copyright (C) 2011-2015 Pulse-Eight Limited.  All rights reserved.
 * libCEC(R) is an original work, containing original code.
 *
 * libCEC(R) is a trademark of Pulse-Eight Limited.
 *
 * This program is dual-licensed; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 *
 *
 * Alternatively, you can license this library under a commercial license,
 * please contact Pulse-Eight Licensing for more information.
 *
 * For more information contact:
 * Pulse-Eight Licensing       <license@pulse-eight.com>
 *     http://www.pulse-eight.com/
 *     http://www.pulse-eight.net/
 */

#include "env.h"

namespace P8PLATFORM
{
  class CEDIDParser
  {
  public:
    static uint16_t GetPhysicalAddress(void);

    static uint16_t GetPhysicalAddressFromEDID(unsigned char *data, size_t size)
    {
      return GetPhysicalAddressFromEDID((char *)data, size);
    }

    static uint16_t GetPhysicalAddressFromEDID(char *data, size_t size)
    {
      uint16_t iPA(0);

      for (size_t iPtr = 0; data && size > 0 && iPtr < size - 4; iPtr++)
      {
        if (data[iPtr]     == 0x03 &&
            data[iPtr + 1] == 0x0C &&
            data[iPtr + 2] == 0x0)
        {
          //found the hdmi marker
          iPA = (data[iPtr + 3] << 8) + data[iPtr + 4];
          break;
        }
      }

      return iPA;
    }
  };
}
